@@ -6,6 +6,7 @@
 
 from .api import (
     init,
+    is_initialized,
     shutdown,
     remote,
     put,
@@ -14,11 +15,13 @@ from .api import (
     is_object_ref,
     get_ip,
     num_cpus,
+    cluster_resources,
 )
 from ._version import get_versions
 
 __all__ = [
     "init",
+    "is_initialized",
     "shutdown",
     "remote",
     "put",
@@ -27,6 +30,7 @@ __all__ = [
     "is_object_ref",
     "get_ip",
     "num_cpus",
+    "cluster_resources",
 ]
 
 __version__ = get_versions()["version"]
